@@ -14,21 +14,45 @@
 -- along with this program; if not, write to the Free Software
 -- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
+
 USE `BIBLEDITDATABASE`;
 
+
 CREATE TABLE IF NOT EXISTS logger (
   pid int,
   logfile varchar(1024)
 ) engine = MyISAM;
 
-DROP PROCEDURE IF EXISTS upgrades;
-DELIMITER ;;
-CREATE PROCEDURE upgrades ()
+
+DROP PROCEDURE IF EXISTS upgrade_one;
+DELIMITER //
+CREATE PROCEDURE upgrade_one () 
 BEGIN
-  DECLARE CONTINUE HANDLER FOR 1060 BEGIN END;
-  DECLARE CONTINUE HANDLER FOR 1061 BEGIN END;
-  DECLARE CONTINUE HANDLER FOR 1091 BEGIN END;
-  ALTER TABLE logger ENGINE = MYISAM;
-END;;
-CALL upgrades();;
-DROP PROCEDURE upgrades;
+  SET @version := (SELECT version FROM version WHERE NAME = 'logger');
+  IF @version IS NULL THEN 
+    ALTER TABLE logger ADD timestamp int;
+    INSERT INTO version VALUES (NULL, 'logger', 1);
+  END IF;
+END;
+//
+DELIMITER ;
+CALL upgrade_one ();
+DROP PROCEDURE upgrade_one;
+
+
+DROP PROCEDURE IF EXISTS upgrade_two;
+DELIMITER //
+CREATE PROCEDURE upgrade_two () 
+BEGIN
+  SET @version := (SELECT version FROM version WHERE NAME = 'logger');
+  IF @version = 1 THEN 
+    ALTER TABLE logger CHANGE timestamp expire int;
+    ALTER TABLE logger ADD process varchar (256);
+    UPDATE version SET version = 2 WHERE name = 'logger';
+  END IF;
+END;
+//
+DELIMITER ;
+CALL upgrade_two ();
+DROP PROCEDURE upgrade_two;
+
