@@ -27,7 +27,7 @@ class Assets_Page
     $view->view->title = $title;
     $view->view->query = $query;
     $view->render ("xhtml_start.php");
-    $view->render ("header_full.php");
+    $view->render ("header.php");
   }
 
   public static function success ($message)
@@ -54,7 +54,7 @@ class Assets_Page
   public static function footer ()
   {
     $view = new Assets_View (__FILE__);
-    $view->render ('footer_full.php');
+    $view->render ('footer.php');
     $view->render ('xhtml_finish.php');
   }
 
