@@ -17,30 +17,40 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
+
 require_once ("../bootstrap/bootstrap.php");
 
+
 $database_logs = Database_Logs::getInstance ();
 $database_logs->log (gettext ("Import Bible data has started"), true);
 
+
 // Security: Page only runs from the cli SAPI.
 if (php_sapi_name () != "cli") {
   $database_logs->log ("Fatal: This only runs through the cli Server API", true);
   die;
 }
 
+
 ignore_user_abort (true);
 set_time_limit (0);
 
+
 $location = $argv[1];
 $bible = $argv[2];
+
+
 $database_logs->log ("Importing from location $location into Bible $bible" , true);
 
-$folder = Filter_Archive::uncompress ($file, true);
+
+$folder = Filter_Archive::uncompress ($location, true);
 if ($folder != NULL) $location = $folder;
 unset ($folder);
 
+
 $files = array ();
 
+
 if (is_dir ($location)) {
   $objects = new RecursiveIteratorIterator(new RecursiveDirectoryIterator($location));
   foreach($objects as $name => $object) {
@@ -52,9 +62,11 @@ if (is_dir ($location)) {
   $files [] = $location;
 }
 
+
 $database_config_user = Database_Config_User::getInstance();
 $stylesheet = $database_config_user->getStylesheet();
 
+
 $database_bibles = Database_Bibles::getInstance();
 $database_snapshots = Database_Snapshots::getInstance();
 $database_books = Database_Books::getInstance ();
@@ -93,6 +105,8 @@ foreach ($files as $file) {
  
 }
 
+
 $database_logs->log ("Import Bible data has finished", true);
 
+
 ?>
