@@ -25,6 +25,7 @@ page_access_level (CONSULTANT_LEVEL);
 $database_changes = Database_Changes::getInstance ();
 $database_notes = Database_Notes::getInstance ();
 $notes_logic = Notes_Logic::getInstance();
+$ipc_notes = Ipc_Notes::getInstance ();
 
 
 // Note unsubscribe handler.
@@ -136,6 +137,11 @@ $timestamp = date ('j F Y', $timestamp);
 $view->view->timestamp = $timestamp;
 
 
+// Whether there's a live notes editor available.
+$live_notes_editor = $ipc_notes->alive ();
+$view->view->live_notes_editor = $live_notes_editor;
+
+
 // Display page.
 $view->render ("change.php");
 
