@@ -49,6 +49,7 @@ if (isset ($navigate)) {
   if ($passage != NULL) {
     $ipc_focus = Ipc_Focus::getInstance();
     $ipc_focus->set ($passage['book'], $passage['chapter'], $passage['verse']);
+    Navigation_Passage::recordHistory ($passage['book'], $passage['chapter'], $passage['verse']);
   }
   // Set the correct default Bible for the user.
   $database_config_user = Database_Config_User::getInstance ();
@@ -60,29 +61,50 @@ if (isset ($navigate)) {
 }
 
 
+// Remove personal change proposals and their matching change notifications.
+if (isset ($_GET ['match'])) {
+  $database_changes->clearMatches ($username, "☺", "♺");
+}
+
+
 $header = new Assets_Header (gettext ("Changes"));
-$header->jQueryOn ();
 $header->run ();
 
 
 $view = new Assets_View (__FILE__);
 
 
-$ids = $database_changes->getIdentifiers ($username);
+$ids = array ();
+@$filter = $_GET ['filter'];
+if ($filter == "personal") {
+  $ids = $database_changes->getPersonalIdentifiers ($username, "☺");
+} else if ($filter == "team") {
+  $ids = $database_changes->getTeamIdentifiers ($username, "♺");
+} else {
+  $ids = $database_changes->getIdentifiers ($username);
+}
 $view->view->ids = $ids;
   
 
 $passages = array ();
+$passageTexts = array ();
+$categories = array ();
 $modifications = array ();
 foreach ($ids as $id) {
   $passage = $database_changes->getPassage ($id);
+  $passages [] = $passage['book'] . "." . $passage['chapter'] . "." . $passage['verse'];
   $passageText = Filter_Books::passagesDisplayInline (array (array ($passage['book'], $passage['chapter'], $passage['verse'])));
   $passageText = Filter_Html::sanitize ($passageText);
-  $passages [] = $passageText;
+  $passageTexts [] = $passageText;
+  $category = $database_changes->getCategory ($id);
+  $category = Filter_Html::sanitize ($category);
+  $categories [] = $category;
   $modification = $database_changes->getModification ($id);
   $modifications [] = $modification;
 }
 $view->view->passages = $passages;
+$view->view->passageTexts = $passageTexts;
+$view->view->categories = $categories;
 $view->view->modifications = $modifications;
 
 
