@@ -25,7 +25,7 @@ class Database_Config_User
   } 
   public static function getInstance() 
   {
-    if ( empty( self::$instance ) ) {
+    if (empty (self::$instance)) {
       self::$instance = new Database_Config_User();
     }
     return self::$instance;
@@ -429,10 +429,10 @@ class Database_Config_User
     $this->setList ("", "active-resources", $values);
   }   
 
-  public function getConsistencyBibles () {
+  public function getConsistencyResources () {
     return $this->getList ("", "consistency-bibles");
   }
-  public function setConsistencyBibles ($values) {
+  public function setConsistencyResources ($values) {
     $this->setList ("", "consistency-bibles", $values);
   }   
 
@@ -460,6 +460,44 @@ class Database_Config_User
     $this->setValue ("", "sprint-progress-notification", $value);
   }   
 
+  public function getUserChangesNotificationsOnline () {
+    return $this->getValue ("", "user-changes-notifications-online", false);
+  }
+  public function getUserUserChangesNotificationsOnline ($username) {
+    return $this->getValueForUser ($username, "user-changes-notifications-online", false);
+  }
+  public function setUserChangesNotificationsOnline ($value) {
+    $this->setValue ("", "user-changes-notifications-online", $value);
+  }   
+
+  public function getWorkbenchURLs () {
+    return $this->getValue ("", "workbench-urls", "");
+  }
+  public function setWorkbenchURLs ($value) {
+    $this->setValue ("", "workbench-urls", $value);
+  }   
+
+  public function getWorkbenchWidths () {
+    return $this->getValue ("", "workbench-widths", "");
+  }
+  public function setWorkbenchWidths ($value) {
+    $this->setValue ("", "workbench-widths", $value);
+  }   
+
+  public function getWorkbenchHeights () {
+    return $this->getValue ("", "workbench-heights", "");
+  }
+  public function setWorkbenchHeights ($value) {
+    $this->setValue ("", "workbench-heights", $value);
+  }
+
+  public function getActiveWorkbench () {
+    return $this->getValue ("", "active-workbench", "");
+  }
+  public function setActiveWorkbench ($value) {
+    $this->setValue ("", "active-workbench", $value);
+  }   
+
 }
 
 
