@@ -25,14 +25,22 @@ class Database_Ipc
   } 
   public static function getInstance() 
   {
-    if ( empty( self::$instance ) ) {
+    if (empty (self::$instance)) {
       self::$instance = new Database_Ipc();
     }
     return self::$instance;
   }
 
 
-  public function optimize () {
+  public function trim ()
+  {
+    $database_instance = Database_Instance::getInstance();
+    $database_instance->runQuery ("DELETE FROM ipc WHERE user = '';");
+  }
+  
+  
+  public function optimize ()
+  {
     $database_instance = Database_Instance::getInstance();
     $database_instance->runQuery ("REPAIR TABLE ipc;");
     $database_instance->runQuery ("OPTIMIZE TABLE ipc;");
@@ -73,6 +81,7 @@ class Database_Ipc
     }
     return $values;
   }
+
   
   public function deleteMessage ($id)
   {
@@ -82,6 +91,7 @@ class Database_Ipc
     $database_instance->runQuery ($query);
   }
 
+
   public function getFocus ()
   {
     $session_logic = Session_Logic::getInstance ();
@@ -89,15 +99,47 @@ class Database_Ipc
     $user = Database_SQLInjection::no ($user);
     $message = array ();
     $database_instance = Database_Instance::getInstance();
-    $query = "SELECT message FROM ipc WHERE command = 'focus' AND (user = '' OR user = '$user') ORDER BY id DESC;";
+    $query = "SELECT message FROM ipc WHERE command = 'focus' AND user = '$user' ORDER BY id DESC;";
     $result = $database_instance->runQuery ($query);
     if ($result->num_rows > 0) {
       $message = $result->fetch_row();
+      return $message[0];
     }
-    return $message[0];
+    // No focus found: Return Genesis 1:1.
+    return "1.1.1";
   }
   
 
+  public function getNote ()
+  {
+    $session_logic = Session_Logic::getInstance ();
+    $user = $session_logic->currentUser ();
+    $user = Database_SQLInjection::no ($user);
+    $database_instance = Database_Instance::getInstance();
+    $query = "SELECT id, message FROM ipc WHERE user = '$user' AND command = 'opennote' ORDER BY id DESC;";
+    $result = $database_instance->runQuery ($query);
+    if ($result->num_rows > 0) {
+      return $result->fetch_assoc ();
+    }
+    return NULL;
+  }
+
+
+  public function getAlive ()
+  {
+    $session_logic = Session_Logic::getInstance ();
+    $user = $session_logic->currentUser ();
+    $user = Database_SQLInjection::no ($user);
+    $database_instance = Database_Instance::getInstance();
+    $query = "SELECT message FROM ipc WHERE user = '$user' AND command = 'notesalive' ORDER BY id DESC;";
+    $result = $database_instance->runQuery ($query);
+    if ($result->num_rows > 0) {
+      $alive = $result->fetch_row ();
+      return $alive [0];
+    }
+    return false;
+  }
+
 
 }
 
