@@ -1,4 +1,21 @@
 <?php
+/*
+Copyright (©) 2003-2013 Teus Benschop.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 3 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+*/
 
 
 /**
@@ -14,8 +31,7 @@ class Dialog_List2
   public function __construct ($header)
   {
     $this->view = new Assets_View (__FILE__);
-    $database_sessions = Database_Sessions::getInstance ();
-    $caller_url = $_SERVER["PHP_SELF"] . "?" . http_build_query (array ("session" => $database_sessions->getCurrentSessionId ()));
+    $caller_url = $_SERVER["PHP_SELF"] . "?" . http_build_query (array ());
     $this->view->view->caller_url = $caller_url;
     $this->view->view->header = $header;
     $this->view->view->info_top = gettext ("Here are the various options:");
