@@ -1,4 +1,21 @@
 <?php
+/*
+Copyright (©) 2003-2013 Teus Benschop.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 3 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+*/
 
 
 /**
@@ -18,8 +35,6 @@ class Dialog_Text
   {
     $this->view = new Assets_View (__FILE__);
     $this->view->view->caller = $_SERVER["PHP_SELF"];
-    $database_sessions = Database_Sessions::getInstance ();
-    $this->view->view->session = $database_sessions->getCurrentSessionId ();
     $this->view->view->header = $header;
     $this->view->view->parameter = $parameter;
     $this->view->view->text = $text;
