@@ -22,34 +22,50 @@ require_once ("../bootstrap/bootstrap.php");
 page_access_level (TRANSLATOR_LEVEL);
 
 
+$database_config_user = Database_Config_User::getInstance ();
+$database_bibles = Database_Bibles::getInstance ();
+
+
 @$switchbook = $_GET ['switchbook'];
 @$switchchapter = $_GET ['switchchapter'];
 if (isset ($switchbook) && isset ($switchchapter)) {
-  $verse = 1;
-  @$switchverse = $_GET ['switchverse'];
-  if ($switchverse) {
-    $switchverse = Filter_Numeric::integer_in_string ($switchverse);
-    $verse = $switchverse;
-  }
   $ipc_focus = Ipc_Focus::getInstance();
   $switchbook = Filter_Numeric::integer_in_string ($switchbook);
   $switchchapter = Filter_Numeric::integer_in_string ($switchchapter);
-  $ipc_focus->set ($switchbook, $switchchapter, $verse);
+  $ipc_focus->set ($switchbook, $switchchapter, 1);
+  Navigation_Passage::recordHistory ($switchbook, $switchchapter, 1);
 }
 
 
 $header = new Assets_Header (gettext ("Edit USFM"));
-$header->jQueryOn ();
+$header->setNavigator ();
 $header->run ();
+
+
+@$changebible = $_GET['changebible'];
+if (isset ($changebible)) {
+  if ($changebible == "") {
+    $dialog_list = new Dialog_List2 (gettext ("Select which Bible to open in the editor"));
+    $bibles = $database_bibles->getBibles ();
+    foreach ($bibles as $bible) {
+      $dialog_list->add_row ($bible, "&changebible=$bible");
+    }
+    $dialog_list->run();
+  } else {
+    $database_config_user->setBible ($changebible);
+  }
+}
+
+
 $view = new Assets_View (__FILE__);
 
 
-$database_config_user = Database_Config_User::getInstance ();
 $bible = $database_config_user->getBible ();
+$view->view->bible = $bible;
 
 
-$view->view->navigationHtml = Navigation_Logic::getContainer ();
-$view->view->navigationCode = Navigation_Logic::code ($bible);
+// Store the active Bible in the page's javascript.
+$view->view->navigationCode = Navigation_Passage::code ($bible);
 
 
 $chapterLoaded = gettext ("Loaded");
