@@ -18,7 +18,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 ?>
 <div>
-  <span><?php echo $this->navigationHtml ?></span>
+  <a href="index.php?changebible="><?php echo $this->bible ?></a>
   |
   <span id="usfmstatus"></span>
 </div>
