@@ -68,6 +68,13 @@ class Filter_Books
     $book = trim ($book);
     $identifier = 0;
     $database_books = Database_Books::getInstance();
+    
+    // Recognize names like "I Peter", where the "I" can also be "II" or "III".
+    // Do the longest ones first.
+    $book = str_replace ("III ", "3 ", $book);
+    $book = str_replace ("II ", "2 ", $book);
+    $book = str_replace ("I ", "1 ", $book);
+
 
     // Check on names entered like "Genesis" or "1 Corinthians", the full English name.
     // A bug was discovered so that "Judges" was interpreted as "Jude", because
