@@ -1,94 +1,95 @@
 <?php
+/*
+Copyright (©) 2003-2013 Teus Benschop.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 3 of the License, or
+(at your option) any later version.
+  
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+  
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+*/
 
 
 class Filter_Git
 {
 
 
-  /**
-  * This filter moves one chapter of the Bible data as it is stored in a git repository, 
-  * using the layout in books and chapters such as is used in Bibledit-Gtk,
-  * and transfers this chapter into Bibledit-Web's Bible database.
-  * The $directory is where the file data resides.
-  * The $bible is the Bible.
-  * The $output is an output line of by git pull.
-  */
-  public static function bibleFiledata2database ($directory, $bible, $output)
-  {
-    // The $output contains one line of the output of "git pull".
-    // A normal action is when a chapter of the Bible is updated as a result of "git pull". 
-    // Example:
-    // Updating 4807e84..0afa0e3
-    // Fast forward
-    // 3 John/1/data |    2 +-
-    // 1 files changed, 1 insertions(+), 1 deletions(-)
-
-    // Find out if the $output refers to a chapter.
-    if (strlen($output) <= 5) return;
-    $bits = explode (DIRECTORY_SEPARATOR, $output);
-    if (count ($bits) < 3) return;
-    $database_books = Database_Books::getInstance ();
-    $bookname = trim ($bits[0]);
-    $bookid = $database_books->getIdFromEnglish ($bookname);
-    if ($bookid == 0) return;
-    $rawchapter = trim ($bits[1]);
-    if ($rawchapter == "") return;
-    $chapter = Filter_Numeric::integer_in_string ($rawchapter);
-    if ($chapter != $rawchapter) return;
-    $datafile = trim ($bits[2]);
-    $datafile = substr ($datafile, 0, 4);
-    if ($datafile != "data") return;
-    $datafile = "$directory/$bookname/$chapter/$datafile";
-
-    // Databases.
-    $database_bibles = Database_Bibles::getInstance ();
-    $database_snapshots = Database_Snapshots::getInstance ();
-    $database_logs = Database_Logs::getInstance();
-
-    // If the $datafile does not exist, it means that the chapter was deleted.
-    if (!file_exists ($datafile)) {
-      $database_bibles->deleteChapter ($bible, $bookid, $chapter);
-      $database_logs->log (gettext ("The collaboration system deleted a chapter") . ": $bible $bookname $chapter");
-      return;
-    }
-    
-    // At this point we are sure that the chapter exists, and has been changed. Read the file's contents.
-    $contents = file_get_contents ($datafile);
-
-    // Check on a conflict, and resolve it.
-    Filter_Git::resolveConflict ($contents, $datafile);
-
-    // Store data into database.
-    $database_bibles->storeChapter ($bible, $bookid, $chapter, $contents);
-    $database_snapshots->snapChapter ($bible, $bookid, $chapter, $contents, false);
-    $database_logs->log (gettext ("The collaboration system updated a chapter") . ": $bible $bookname $chapter");
-  }
-
-
-  /**
-  * This filter takes the Bible data as it is stored in Bibledit-Web's database, 
-  * and transfers this information into the layout in books and chapters
-  * such as is used in Bibledit-Gtk into $directory.
-  * The $directory may contain other data. This data will not normally be affected.
-  */
-  public static function bibleDatabase2filedata ($bible, $directory, $progress = false)
+  // This filter takes the Bible data as it is stored in Bibledit-Web's database, 
+  // and puts this information into the layout in books and chapters
+  // such as is used in Bibledit-Gtk into the $git folder.
+  // The $git is a git repository, and may contain other data as well.
+  // The filter focuses on reading the data in the git repository, and only writes to it if necessary, 
+  // This speeds up the filter.
+  public static function syncBible2Git ($bible, $git, $progress = false)
   {
     $success = true;
+
     $database_bibles = Database_Bibles::getInstance ();
     $database_books = Database_Books::getInstance ();
+
+    // First stage.
+    // Read the chapters in the git repository, 
+    // and check if they occur in the database.
+    // If a chapter is not in the database, remove it from the repository.
+    $books = $database_bibles->getBooks ($bible);
+    foreach (new DirectoryIterator ($git) as $fileInfo) {
+      if ($fileInfo->isDot ()) continue;
+      if ($fileInfo->isDir ()) {
+        $bookname = $fileInfo->getFilename ();
+        $book = $database_books->getIdFromEnglish ($bookname);
+        if ($book) {
+          if (in_array ($book, $books)) {
+            // Book exists in the database: Check the chapters.
+            $chapters = $database_bibles->getChapters ($bible, $book);
+            foreach (new DirectoryIterator ("$git/$bookname") as $fileInfo2) {
+              if ($fileInfo2->isDot ()) continue;
+              if ($fileInfo2->isDir ()) {
+                $chapter = $fileInfo2->getFilename ();
+                if (is_numeric ($chapter)) {
+                  $filename = "$git/$bookname/$chapter/data";
+                  if (file_exists ($filename)) {
+                    if (!in_array ($chapter, $chapters)) {
+                      // Chapter does not exist in the database.
+                      Filter_Rmdir::rmdir ("$git/$bookname/$chapter");
+                    }
+                  }
+                }
+              }
+            }
+          } else {
+            // Book does not exist in the database: Remove it from $git.
+            Filter_Rmdir::rmdir ("$git/$bookname");
+          }
+        }
+      }
+    }
+
+    // Second stage.
+    // Read the books / chapters from the database, 
+    // and check if they occur in the repository, and the data matches.
+    // If necessary, save the chapter to the repository.
     $books = $database_bibles->getBooks ($bible);
     foreach ($books as $book) {
-      $book_name = $database_books->getEnglishFromId ($book);
-      if ($progress) echo "$book_name ";
-      $bookdir = "$directory/$book_name";
-      if (!is_dir ($bookdir)) mkdir ($bookdir);
+      $bookname = $database_books->getEnglishFromId ($book);
+      if ($progress) echo "$bookname ";
+      $bookdir = "$git/$bookname";
+      if (!file_exists ($bookdir)) mkdir ($bookdir);
       $chapters = $database_bibles->getChapters ($bible, $book);
       foreach ($chapters as $chapter) {
         $chapterdir = "$bookdir/$chapter";
-        if (!is_dir ($chapterdir)) mkdir ($chapterdir);
-        $data = $database_bibles->getChapter ($bible, $book, $chapter);
-        if (file_put_contents ("$chapterdir/data", $data) === false)
-          $success = false;
+        if (!file_exists ($chapterdir)) mkdir ($chapterdir);
+        $datafile = "$chapterdir/data";
+        @$contents = file_get_contents ($datafile);
+        $usfm = $database_bibles->getChapter ($bible, $book, $chapter);
+        if ($contents != $usfm) file_put_contents ($datafile, $usfm);
       }
     }
     if ($progress) echo "\n";
@@ -96,6 +97,92 @@ class Filter_Git
   }
 
 
+  // This filter takes the Bible data as it is stored in the $git folder, 
+  // and puts this information into Bibledit-Web's database.
+  // The $git is a git repository, and may contain other data as well.
+  // The filter focuses on reading the data in the git repository and the database,
+  // and only writes to the database if necessary, 
+  // This speeds up the filter.
+  public static function syncGit2Bible ($git, $bible)
+  {
+    $success = true;
+
+    $database_bibles = Database_Bibles::getInstance ();
+    $database_books = Database_Books::getInstance ();
+    $database_logs = Database_Logs::getInstance ();
+
+    // Stage one:
+    // Read the chapters in the git repository,
+    // and check that they occur in the database.
+    // If any does not occur, add the chapter to the database.
+    // This stage does not check the contents of the chapters.
+    $books = $database_bibles->getBooks ($bible);
+    foreach (new DirectoryIterator ($git) as $fileInfo) {
+      if ($fileInfo->isDot ()) continue;
+      if ($fileInfo->isDir ()) {
+        $bookname = $fileInfo->getFilename ();
+        $book = $database_books->getIdFromEnglish ($bookname);
+        if ($book) {
+          // Check the chapters.
+          $chapters = $database_bibles->getChapters ($bible, $book);
+          foreach (new DirectoryIterator ("$git/$bookname") as $fileInfo2) {
+            if ($fileInfo2->isDot ()) continue;
+            if ($fileInfo2->isDir ()) {
+              $chapter = $fileInfo2->getFilename ();
+              if (is_numeric ($chapter)) {
+                $filename = "$git/$bookname/$chapter/data";
+                if (file_exists ($filename)) {
+                  if (!in_array ($chapter, $chapters)) {
+                    // Chapter does not exist in the database: Add it.
+                    $usfm = file_get_contents ($filename);
+                    $database_bibles->storeChapter ($bible, $book, $chapter, $usfm);
+                    $database_logs->log (gettext ("A translator added chapter") . " $bible $bookname $chapter");
+                  }
+                }
+              }
+            }
+          }
+        }
+      }
+    }
+    
+    
+    // Stage two:
+    // Read through the chapters in the database,
+    // and check that they occur in the git folder.
+    // If necessary, remove a chapter from the database.
+    // If a chapter matches, check that the contents of the data in the git 
+    // folder and the contents in the database match.
+    // If necessary, update the data in the database.
+    $books = $database_bibles->getBooks ($bible);
+    foreach ($books as $book) {
+      $bookname = $database_books->getEnglishFromId ($book);
+      $bookdir = "$git/$bookname";
+      if (file_exists ($bookdir)) {
+        $chapters = $database_bibles->getChapters ($bible, $book);
+        foreach ($chapters as $chapter) {
+          $chapterdir = "$bookdir/$chapter";
+          if (file_exists ($chapterdir)) {
+            $datafile = "$chapterdir/data";
+            $contents = file_get_contents ($datafile);
+            $usfm = $database_bibles->getChapter ($bible, $book, $chapter);
+            if ($contents != $usfm) {
+              $database_bibles->storeChapter ($bible, $book, $chapter, $contents);
+              $database_logs->log (gettext ("A translator updated chapter") . " $bible $bookname $chapter");
+           }
+          } else {
+            $database_bibles->deleteChapter ($bible, $book, $chapter);
+            $database_logs->log (gettext ("A translator deleted chapter") . " $bible $bookname $chapter");
+         }
+        }
+      } else {
+        $database_bibles->deleteBook ($bible, $book);
+        $database_logs->log (gettext ("A translator deleted book") . " $bible $bookname");
+      }
+    }
+  }
+
+
   /**
   * This filter takes the Consultations Notes as these are stored in Bibledit-Web's database, 
   * and transfers this information to the file system,
@@ -142,7 +229,7 @@ class Filter_Git
       $data [] = "Severity:";
       $data [] = $database_notes->getRawSeverity ($identifier);
       $data [] = "Privacy:";
-      $data [] = $database_notes->getPrivacy ($identifier);
+      $data [] = 0;
       $data [] = "Summary:";
       $data [] = $database_notes->getSummary ($identifier);
       $data [] = "Contents:";
@@ -201,9 +288,6 @@ class Filter_Git
     // Read the file's contents.
     $contents = file_get_contents ($datafile);
 
-    // Check on a conflict, and resolve it automatically.
-    Filter_Git::resolveConflict ($contents, $datafile);
-
     // Start importing the note.
 
     if (!$database_notes->identifierExists ($identifier)) {
@@ -294,10 +378,8 @@ class Filter_Git
           break;
         case "Summary:":
           // This heading follows the Privacy: heading, hence the note's privacy is stored here.
+          // Privacy no longer works.
           @$privacy = $fielddata[0];
-          if ($privacy != $database_notes->getPrivacy ($identifier)) {
-            $database_notes->setPrivacy ($identifier, $privacy);
-          }
           unset ($fielddata);
           break;
         case "Contents:":
@@ -350,112 +432,6 @@ class Filter_Git
     return $directory;
   }
   
-  
-  public static function filedata2database ()
-  {
-    $database_git = Database_Git::getInstance();
-    while ($database_git->get()) {
-      $entry = $database_git->get ();
-      $directory = $entry['directory'];
-      $output = $entry['output'];
-      $object = basename ($directory);
-      if ($object == "consultationnotes") {
-        Filter_Git::notesFiledata2database ($directory, $output);
-      } else {
-        Filter_Git::bibleFiledata2database ($directory, $object, $output);
-      }
-      $database_git->delete ($directory, $output);
-    }
-  }
-  
-  
-  /*
-   * This resolves a git conflict in $contents.
-   * If there is a conflict, it modifies $contents.
-   * It saves the modified $contents to $filename.  
-   */
-  public static function resolveConflict (&$contents, $filename)
-  {
-    /*
-    The first thing to do is to see whether there is a conflict.
-    In most cases all is fine. Then the function returns.
-    If there is a conflicting merge after doing a 'git pull', the $contents looks like this:
-    
-    <<<<<<< HEAD:3 John/1/data
-    \v 1 xFrom the church leader.
-    =======
-    \v 1 xxFrom the church leader.
-    >>>>>>> a62f843ce41ed2d0325c8a2767993df6acdbc933:3 John/1/data
-
-    or like this:
-
-    \c 1
-    <<<<<<< HEAD:3 John/1/data
-    \v 1 my text.
-    =======
-    \v 1 server's text.
-    >>>>>>> a62f843ce41ed2d0325c8a2767993df6acdbc933:3 John/1/data
-    \v 2
-
-    */
-    if (strpos ($contents, "<<<<<<< HEAD") === FALSE) return;
-
-    $database_logs = Database_Logs::getInstance ();
-    
-    // The $contents is a string, change it to an array.
-    $lines = explode ("\n", $contents);
-
-    // Set about to resolve the conflict.
-    $newdata = array ();
-    $withinmine = false;
-    $withinserver = false;
-    foreach ($lines as $line) {
-      // Find out when we've got a marker, no actual data.    
-      $minemarker = (strpos ($line, "<<<<<<< HEAD") !== FALSE);
-      $separatormarker = ($line == "=======");
-      $servermarker = (strpos ($line, ">>>>>>> ") !== FALSE);
-      // Do conflict management only if we've actual data.
-      $takeit = false;
-      if (!$minemarker && !$separatormarker && !$servermarker) {
-        if ($withinmine) {
-          $database_logs->log ("Merge conflict, my data: " . $line);
-          //if ($conflicthandling == $TakeMe)
-          if (false)
-            $takeit = true;
-        } else if ($withinserver) {
-          $database_logs->log ("Merge conflict, server data: " . $line);
-          //if ($conflicthandling == $TakeServer)
-          if (true)
-            $takeit = true;
-        } else {
-          $takeit = true;
-        }
-      }
-      if ($takeit) {
-        $newdata [] = $line;
-      } else {
-      }
-      // Set whether we're within a conflict, my data, or the server's data.
-      // This setting applies to the next line of data.
-      if ($minemarker) {
-        $withinmine = true;
-        $withinserver = false;
-      }
-      if ($separatormarker) {
-        $withinmine = false;
-        $withinserver = true;
-      }
-      if ($servermarker) {
-        $withinmine = false;
-        $withinserver = false;
-      }
-    }
-    $contents = implode ("\n", $newdata);
-
-    file_put_contents ($filename, $contents);
-  }
-          
-      
 
 }
 
