@@ -709,7 +709,7 @@ class Filter_Text
                 // Deal with the case of a pending chapter number.
                 if (isset ($this->outputChapterTextAtFirstVerse)) {
                   $database_config_general = Database_Config_General::getInstance ();
-                  if ($database_config_general->getExportChapterDropCaps ()) {
+                  if (!$database_config_general->getExportChapterDropCaps ()) {
                     $dropCapsLength = mb_strlen ($this->outputChapterTextAtFirstVerse);
                     $this->applyDropCapsToCurrentParagraph ($dropCapsLength);
                     if ($this->odf_text_standard) $this->odf_text_standard->addText ($this->outputChapterTextAtFirstVerse);
