@@ -18,8 +18,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 ?>
 <h1><?php echo gettext ("About") ?></h1>
-<p><?php echo gettext ("Bibledit-Web") ?> {$version}</p>
-<p><a href="http://bibledit.org">http://bibledit.org</a></p>
+<p><?php echo gettext ("Bibledit-Web") ?> <?php echo $this->version ?></p>
+<p><a href="https://sites.google.com/site/bibleditweb">https://sites.google.com/site/bibleditweb</a></p>
 <p>Copyright (©) 2003-2013 Teus Benschop.</p>
 <p>This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.</p>
 <p>This program is distributed in the hope that it will be useful, but without any warranty; without even the implied warranty of merchantability or fitness for a particular purpose. See the GNU General Public License for more details.</p>
@@ -28,7 +28,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 <p><a href="changelog.php">ChangeLog</a></p>
 <br>
 <p><?php echo gettext ("While Bibledit-Web may be used for making any Bibles, there are some distinct advantages to releasing Bibles under an open license.") ?></p>
-<p><?php echo gettext ("* Others's will feel free to publish the open Bible, so that you don't need to do everything yourself: Others will help spreading the Word of God.") ?></p>
+<p><?php echo gettext ("* Others will feel free to publish the open Bible. You don't need to do everything yourself: Others will help spreading the Word of God.") ?></p>
 <p><?php echo gettext ("* It becomes easy to publish Bibles in a variety of formats by a variety of people: on paper, phones, the Internet.") ?></p>
 <p><?php echo gettext ("* If you think that the Bible you translated is good and reliable, and you release it under an open license, it will rapidly spread over the Internet.") ?></p>
 <p><?php echo gettext ("* Compare an open Bible to the Greek minuscules: They were copied freely, and they can now be found all over the place.") ?></p>
