@@ -20,6 +20,57 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 <h1>ChangeLog</h1>
 
 <h2>Version in repository</h2>
+<p></p>
+<p></p>
+<p></p>
+<p></p>
+<p></p>
+<p></p>
+<p></p>
+
+<h2>Version 1.2</h2>
+<p>12 October 2013</p>
+<p>The tool to remove duplicate consultation notes was renamed to "Clean Consultation Notes".</p>
+<p>The tool to clean the consultation notes converts the note summaries to clean text.</p>
+<p>Users can opt for having their personal change proposals visible among the Change Notifications online.</p>
+<p>The logbook shows for which day of the month the sprint history gets updated.</p>
+<p>The clickable elements of the Navigator have titles that show up if the mouse hovers over the links.</p>
+<p>The Navigator has a link ↶ for going back in the navigation history, and a link ↷ for going forward.</p>
+<p>The Navigator responds to the Alt-Left arrow key press by going back. Alt-Right goes forward.</p>
+<p>Personal change proposals are marked with ☺ in the change notifications, and changes in the team's Bible are marked with ♺.</p>
+<p>Automatically remove personal change proposals and their matching change notifications.</p>
+<p>Updated information about typesetting.</p>
+<p>Some bugs in the styles editor were fixed.</p>
+<p>The sprint burndown chart gives the business days only, so the graph is smoother and more realistic.</p>
+<p>The Spint page uses completion categories for the tasks instead of percentages.</p>
+<p>The Sprint page focuses the entry for adding new tasks when a new task has just been added.</p>
+<p>Export to e-Sword now also works with Bibles that have spaces in their names.</p>
+<p>Compresses USFM files to a zip file during export.</p>
+<p>Fix: Uploading a zipped file with USFM files imports the USFM files.</p>
+<p>The table for storing Bible data in the database was optimized for better performance.</p>
+<p>Pages not found redirect to the home page.</p>
+<p>Bibledit-Web now has its own repository and project hosted at https://savannah.nongnu.org/projects/bibledit-web.</p>
+<p>Bibledit-Web now has its own wiki at https://sites.google.com/site/bibleditweb.</p>
+<p>The yellow highlighting no longer affects the capitalization of the search results.</p>
+<p>A default external resource has been added that displays the Elberfelder Bibel from www.bibleserver.com.</p>
+<p>Recognizes Roman numerals like I, II and III in book names.</p>
+<p>Workbench to display internal and/or external pages side by side.</p>
+<p>Selectable workbench configurations.</p>
+<p>The user can view all the change notifications, only the personal ones, or only the team ones.</p>
+<p>All pages use jQuery.</p>
+<p>The Navigator has moved to the top bar.</p>
+<p>Bibledit-Web processes running for more than five hours get killed as they are considered stuck.</p>
+<p>Edit two or more Bibles simultaneously side by side in a workbench.</p>
+<p>The interlinear Bible from biblehub.com has been added to the Resources.</p>
+<p>Requires program "tidy".</p>
+<p>The text of the Dutch Statenbijbel has been added to the Resources.</p>
+<p>The Resources include the Dutch Statenbijbel Plus: The canonical text, plus headers, introductions, cross references, and notes.</p>
+<p>Clicking passages on some Resources navigates to that passage.</p>
+<p>Clicking a passage in the Change Notificatons navigates to that passage.</p>
+<p>Two new resources: King James Version with only canonical text, and one with all the headers, introductions, cross references, and notes as well.</p>
+<p>The notes editor has some preset selections to be activated from the URL.</p>
+<p>Activating notes from the change notifications opens the notes in an existing note editor if available, else in a new tab in the browser.</p>
+<p>The USFM editor saves the text more reliably at page unload.</p>
 
 <h2>Version 1.1</h2>
 <p>20 September 2013</p>
@@ -44,7 +95,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 <p>Requires program "merge" in package "rcs".</p>
 <p>Resolves conflicts during Send/receive by merging the two versions with grapheme granularity.</p>
 <p>The Sword module export links to information about Sword module making.</p>
-<p>The installer sets the maximum size of file uploads to 8 Mbyte PHP.</p>
+<p>The installer sets the maximum size of file uploads to 8 Mbyte for PHP.</p>
 <p>Time consuming operations on Bibles no longer time out.</p>
 <p>Does not delete session files younger than the cookie timeout of 12 hours.</p>
 <p>The consultation notes editor is as wide as the browser window.</p>
@@ -53,13 +104,11 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 <p>Pasting text into the consultation notes editor converts it to plain text.</p>
 <p>There is a tool for checking the consistency of the Bible translation.</p>
 <p>Subscribed users get a daily email detailing the changes they have entered in the web-based Bible editor.</p>
-<p>The caret of the USFM editor scrolls the center of the browser window.</p>
-<p>A moving vertical yellow arrow points to the position of the caret in the Bible editor.</p>
+<p>The caret of the USFM editor scrolls to the center of the browser window.</p>
+<p>A vertically moving yellow arrow points to the position of the caret in the Bible editor.</p>
 <p>Tasks can be defined for a sprint, and moved to another sprint.</p>
 <p>The percentage complete can be set for each task in steps.</p>
 <p>Sends weekly email with the sprint planning and a burndown chart to subscribed users.</p>
-<p></p>
-<p></p>
 
 <h2>Version 1.0</h2>
 <p>30 July 2013</p>
