@@ -16,11 +16,11 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 $(document).ready (function () {
-  $(document).on ("passage", loadNotes);
+  navigationNewPassage ();
 });
 
 
-function loadNotes ()
+function navigationNewPassage ()
 {
   $.get ("notes.php", function (response) {
     var container = $ ("#noteslist");
