@@ -19,7 +19,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 require_once ("../bootstrap/bootstrap.php");
 page_access_level (CONSULTANT_LEVEL);
 $header = new Assets_Header (gettext ("Resources"));
-$header->jQueryOn ();
+$header->setNavigator ();
 $header->run ();
 $view = new Assets_View (__FILE__);
 
@@ -31,10 +31,6 @@ $resource_count = count ($resources);
 $script = "var resourceCount = $resource_count;";
 $view->view->script = $script;
 
-$view->view->navigationHtml = Navigation_Logic::getContainer ();
-
-$view->view->navigationCode = Navigation_Logic::code ("");
-
 $view->render ("index.php");
 Assets_Page::footer ();
 ?>
