@@ -40,6 +40,7 @@ set_time_limit (0);
 
 
 $config_general = Database_Config_General::getInstance ();
+$database_logs = Database_Logs::getInstance ();
 $timer_logger = new Timer_Logger ();
 //$processUser = posix_getpwuid(posix_geteuid());
 //$processUser = $processUser['name'];
@@ -54,26 +55,20 @@ $hour = date ('G');
 $minute = date ('i');
 
 
-// Every minute send out any queued mail.
-$workingdirectory = escapeshellarg (dirname (__FILE__));
-$logfilename = $timer_logger->getLogFilename (Timer_Logger::mailer);
-$command = "cd $workingdirectory; php mailer.php > $logfilename 2>&1 & echo $!";
-$pid = shell_exec ($command);
-$timer_logger->registerLogfile ($command, $pid, $logfilename, false);
-
-
+// Every minute check on processes that are stuck.
+$timer_logger->killExpiredPIDs ();
 // Every minute deal with any log files that were used for the scripts.
 $timer_logger->handleUsedLogFiles ();
 
 
+// Every minute send out any queued mail.
+$timer_logger->startProcess (dirname (__FILE__), "php", "mailer.php", NULL, NULL, false);
+
+
 // Check for new mail every five minutes.
 // Do not check more often with gmail else the account may be shut down.
 if (($minute % 5) == 0) {
-  $workingdirectory = escapeshellarg (dirname (__FILE__));
-  $logfilename = $timer_logger->getLogFilename (Timer_Logger::receiver);
-  $command = "cd $workingdirectory; php receiver.php > $logfilename 2>&1 & echo $!";
-  $pid = shell_exec ($command);
-  $timer_logger->registerLogfile ($command, $pid, $logfilename, false);
+  $timer_logger->startProcess (dirname (__FILE__), "php", "receiver.php", NULL, NULL, false);
 }
 
 
@@ -94,29 +89,24 @@ if ((($minute % 5) == 0) && $config_general->getRepeatSendReceive ()) $sendrecei
 if ($sendreceive) {
   if (!SendReceive_Logic::isRunning ()) {
     SendReceive_Logic::start ();
+  } else {
+    $database_logs->log ("Intending to Send/Receive, but the process is already running");
   }
 }
 
 
-// Sending the daily changes in the Bibles by email.
-// This takes a few minutes on a production machine with two Bibles and changes in several chapters.
-if (($current_timestamp >= $config_general->getTimerDiff ()) || (($hour == 0) && ($minute == 20))) {
-  $config_general->setTimerDiff ($current_timestamp + 100000);
-  $workingdirectory = escapeshellarg (dirname (__FILE__));
-  $logfilename = $timer_logger->getLogFilename (Timer_Logger::changes);
-  $command = "cd $workingdirectory; php changes.php > $logfilename 2>&1 & echo $!";
-  $pid = shell_exec ($command);
-  $timer_logger->registerLogfile ($command, $pid, $logfilename);
+// Deal with the changes in the Bible made per user.
+// It should run before the general changes to influence the order of the notifications in the GUI.
+if (($hour == 0) && ($minute == 20)) {
+  $timer_logger->startProcess (dirname (__FILE__), "php", "userchanges.php", NULL, NULL, true);
 }
 
 
-// Deal with the changes in the Bible made per user.
-if (($hour == 0) && ($minute == 25)) {
-  $workingdirectory = escapeshellarg (dirname (__FILE__));
-  $logfilename = $timer_logger->getLogFilename (Timer_Logger::userchanges);
-  $command = "cd $workingdirectory; php userchanges.php > $logfilename 2>&1 & echo $!";
-  $pid = shell_exec ($command);
-  $timer_logger->registerLogfile ($command, $pid, $logfilename);
+// Deal with notifications for the daily changes in the Bibles.
+// This takes a few minutes on a production machine with two Bibles and changes in several chapters.
+if (($current_timestamp >= $config_general->getTimerDiff ()) || (($hour == 0) && ($minute == 25))) {
+  $config_general->setTimerDiff ($current_timestamp + 100000);
+  $timer_logger->startProcess (dirname (__FILE__), "php", "changes.php", NULL, NULL, true);
 }
 
 
@@ -124,22 +114,14 @@ if (($hour == 0) && ($minute == 25)) {
 // This takes 15 minutes on a production machine with two Bibles.
 if (($current_timestamp >= $config_general->getTimerChecks ()) || (($hour == 0) && ($minute == 30))) {
   $config_general->setTimerChecks ($current_timestamp + 100000);
-  $workingdirectory = dirname (__FILE__);
-  $logfilename = $timer_logger->getLogFilename (Timer_Logger::checks);
-  $command = "cd $workingdirectory; php checks.php > $logfilename 2>&1 & echo $!";
-  $pid = shell_exec ($command);
-  $timer_logger->registerLogfile ($command, $pid, $logfilename);
+  $timer_logger->startProcess (dirname (__FILE__), "php", "checks.php", NULL, NULL, true);
 }
 
 
 // Database maintenance and trimming.
 // It takes a few minutes on a production machine..
 if (($hour == 0) && ($minute == 50)) {
-  $workingdirectory = dirname (__FILE__);
-  $logfilename = $timer_logger->getLogFilename (Timer_Logger::database);
-  $command = "cd $workingdirectory; php database.php > $logfilename 2>&1 & echo $!";
-  $pid = shell_exec ($command);
-  $timer_logger->registerLogfile ($command, $pid, $logfilename);
+  $timer_logger->startProcess (dirname (__FILE__), "php", "database.php", NULL, NULL, true);
 }
 
 
@@ -147,21 +129,13 @@ if (($hour == 0) && ($minute == 50)) {
 // after the previous tasks have been done.
 if (($current_timestamp >= $config_general->getTimerBackup ()) || (($hour == 0) && ($minute == 55))) {
   $config_general->setTimerBackup ($current_timestamp + 100000);
-  $workingdirectory = dirname (__FILE__);
-  $logfilename = $timer_logger->getLogFilename (Timer_Logger::backup);
-  $command = "cd $workingdirectory; php backup.php > $logfilename 2>&1 & echo $!";
-  $pid = shell_exec ($command);
-  $timer_logger->registerLogfile ($command, $pid, $logfilename);
+  $timer_logger->startProcess (dirname (__FILE__), "php", "backup.php", NULL, NULL, true);
 }
 
 
 // Email statistics to the users.
 if (($hour == 1) && ($minute == 0)) {
-  $workingdirectory = escapeshellarg (dirname (__FILE__));
-  $logfilename = $timer_logger->getLogFilename (Timer_Logger::statistics);
-  $command = "cd $workingdirectory; php statistics.php > $logfilename 2>&1 & echo $!";
-  $pid = shell_exec ($command);
-  $timer_logger->registerLogfile ($command, $pid, $logfilename);
+  $timer_logger->startProcess (dirname (__FILE__), "php", "statistics.php", NULL, NULL, true);
 }
 
 
@@ -183,21 +157,15 @@ unset ($burndown);
 // This may take an hour on a production machine.
 if (($current_timestamp >= $config_general->getTimerExports ()) || (($hour == 1) && ($minute == 10))) {
   $config_general->setTimerExports ($current_timestamp + 100000);
-  $workingdirectory = escapeshellarg (dirname (__FILE__));
-  $logfilename = $timer_logger->getLogFilename (Timer_Logger::exports);
-  $command = "cd $workingdirectory; php exports.php > $logfilename 2>&1 & echo $!";
-  $pid = shell_exec ($command);
-  $timer_logger->registerLogfile ($command, $pid, $logfilename);
+  $timer_logger->startProcess (dirname (__FILE__), "php", "exports.php", NULL, NULL, true);
 }
 
 
 // Clear the past sessions.
 if (($hour == 2) && ($minute == 0)) {
   $sessions_path = dirname (__FILE__) . "/../session";
-  $logfilename = $timer_logger->getLogFilename (Timer_Logger::sessions);
-  $command = "php sessions.php $sessions_path > $logfilename 2>&1 & echo $!";
-  $pid = shell_exec ($command);
-  $timer_logger->registerLogfile ($command, $pid, $logfilename);
+  $parameters = array ($sessions_path);
+  $timer_logger->startProcess (dirname (__FILE__), "php", "sessions.php", $parameters, NULL, true);
 }
 
 
